@@ -6,7 +6,6 @@ import random
 import matplotlib as mpl
 import matplotlib.pyplot as plt
 import numpy as np
-from matplotlib import docstring
 from matplotlib.projections.polar import PolarAxes
 from numpy.lib.twodim_base import histogram2d
 
@@ -15,11 +14,25 @@ VAR_DEFAULT = "speed"
 DIR_DEFAULT = "direction"
 FIGSIZE_DEFAULT = (8, 8)
 DPI_DEFAULT = 80
-CALM_CIRCLE_COLOR = "red"
-CALM_CIRCLE_ALPHA = 0.4
 DEFAULT_THETA_LABELS = ["E", "N-E", "N", "N-W", "W", "S-W", "S", "S-E"]
 
 
+def _copy_docstring(source):
+    """
+
+    Copy the docstring from another function.
+    Implemented according to: https://github.com/matplotlib/matplotlib/blob/b5ac96a8980fdb9e59c9fb649e0714d776e26701/lib/matplotlib/_docstring.py#L86-L92
+
+    """  # noqa: E501
+
+    def inner(target):
+        if source.__doc__ is not None:
+            target.__doc__ = source.__doc__
+        return target
+
+    return inner
+
+
 class WindAxesFactory:
     """
 
@@ -112,7 +125,7 @@ class WindroseAxes(PolarAxes):
                 )
             if rect is None:
                 rect = [0.1, 0.1, 0.8, 0.8]
-            ax = WindroseAxes(fig, rect, rmax=rmax, *args, **kwargs)
+            ax = WindroseAxes(fig, rect, *args, **kwargs)
             fig.add_axes(ax)
             return ax
         else:
@@ -127,9 +140,9 @@ class WindroseAxes(PolarAxes):
         self.theta_angles = np.arange(0, 360, 45)
         self.set_thetagrids(angles=self.theta_angles, labels=self.theta_labels)
 
-        self._info = {"dir": list(), "bins": list(), "table": list()}
+        self._info = {"dir": [], "bins": [], "table": []}
 
-        self.patches_list = list()
+        self.patches_list = []
 
         self.calm_count = None
 
@@ -208,10 +221,11 @@ class WindroseAxes(PolarAxes):
         """
 
         def get_handles():
-            handles = list()
+            handles = []
             for p in self.patches_list:
                 if isinstance(p, mpl.patches.Polygon) or isinstance(
-                    p, mpl.patches.Rectangle
+                    p,
+                    mpl.patches.Rectangle,
                 ):
                     color = p.get_facecolor()
                 elif isinstance(p, mpl.lines.Line2D):
@@ -220,13 +234,16 @@ class WindroseAxes(PolarAxes):
                     raise AttributeError("Can't handle patches")
                 handles.append(
                     mpl.patches.Rectangle(
-                        (0, 0), 0.2, 0.2, facecolor=color, edgecolor="black"
-                    )
+                        (0, 0),
+                        0.2,
+                        0.2,
+                        facecolor=color,
+                        edgecolor="black",
+                    ),
                 )
             return handles
 
         def get_labels(decimal_places=1, units=None):
-
             digits = np.copy(self._info["bins"]).tolist()
             if not digits:
                 return ""
@@ -252,7 +269,7 @@ class WindroseAxes(PolarAxes):
 
         handles = get_handles()
         labels = get_labels(decimal_places, units)
-        self.legend_ = mpl.legend.Legend(self, handles, labels, loc, **kwargs)
+        self.legend_ = mpl.legend.Legend(self, handles, labels, loc=loc, **kwargs)
         return self.legend_
 
     def set_legend(self, **pyplot_arguments):
@@ -290,6 +307,20 @@ class WindroseAxes(PolarAxes):
             Any argument accepted by :obj:`matplotlib.pyplot.plot`.
         """
 
+        normed = kwargs.pop("normed", False)
+        blowto = kwargs.pop("blowto", False)
+
+        # Calm condition, mask data if needed
+        calm_limit = kwargs.pop("calm_limit", None)
+        total = len(var)
+        if calm_limit is not None:
+            mask = var > calm_limit
+            self.calm_count = len(var) - np.count_nonzero(mask)
+            if normed:
+                self.calm_count = self.calm_count * 100 / len(var)
+            var = var[mask]
+            direction = direction[mask]
+
         # if weibull factors are entered overwrite direction and var
         if "weibull_factors" in kwargs or "mean_values" in kwargs:
             if "weibull_factors" in kwargs and "mean_values" in kwargs:
@@ -304,7 +335,7 @@ class WindroseAxes(PolarAxes):
             if val:
                 if "frequency" not in kwargs:
                     raise TypeError(
-                        "specify 'frequency' argument for statistical input"
+                        "specify 'frequency' argument for statistical input",
                     )
                 windFrequencies = kwargs.pop("frequency")
                 if len(windFrequencies) != len(direction) or len(direction) != len(var):
@@ -318,11 +349,14 @@ class WindroseAxes(PolarAxes):
                     for _ in range(int(windFrequencies[dbin] * 10000)):
                         if statistic_type == "weibull":
                             windSpeeds.append(
-                                random.weibullvariate(var[dbin][0], var[dbin][1])
+                                random.weibullvariate(var[dbin][0], var[dbin][1]),
                             )
                         elif statistic_type == "mean":
                             windSpeeds.append(
-                                random.weibullvariate(var[dbin] * 2 / np.sqrt(np.pi), 2)
+                                random.weibullvariate(
+                                    var[dbin] * 2 / np.sqrt(np.pi),
+                                    2,
+                                ),
                             )
                         windDirections.append(direction[dbin])
                 var, direction = windSpeeds, windDirections
@@ -361,41 +395,23 @@ class WindroseAxes(PolarAxes):
         # Building the angles list
         angles = np.arange(0, -2 * np.pi, -2 * np.pi / nsector) + np.pi / 2
 
-        normed = kwargs.pop("normed", False)
-        blowto = kwargs.pop("blowto", False)
-
-        # Calm condition
-        calm_limit = kwargs.pop("calm_limit", None)
-        if calm_limit is not None:
-            mask = var > calm_limit
-            self.calm_count = len(var) - np.count_nonzero(mask)
-            if normed:
-                self.calm_count = self.calm_count * 100 / len(var)
-            var = var[mask]
-            direction = direction[mask]
-
         # Set the global information dictionary
         self._info["dir"], self._info["bins"], self._info["table"] = histogram(
-            direction, var, bins, nsector, normed, blowto
+            direction,
+            var,
+            bins,
+            nsector,
+            normed,
+            blowto,
+            total,
         )
 
         return bins, nbins, nsector, colors, angles, kwargs
 
     def _calm_circle(self):
-        """
-        Draw the calm centered circle
-        and return the initial offset for plots methods
-        """
+        """Draw the calm centered circle"""
         if self.calm_count and self.calm_count > 0:
-            circle = mpl.patches.Circle(
-                (0.0, 0.0),
-                self.calm_count,
-                transform=self.transData._b,
-                color=CALM_CIRCLE_COLOR,
-                alpha=CALM_CIRCLE_ALPHA,
-            )
-            self.add_artist(circle)
-        return self.calm_count or 0
+            self.set_rorigin(-(np.sqrt(self.calm_count / np.pi)))
 
     def contour(self, direction, var, **kwargs):
         """
@@ -413,9 +429,9 @@ class WindroseAxes(PolarAxes):
 
         Other Parameters
         ----------------
-        sector : integer, optional
+        nsector : integer, optional
             number of sectors used to compute the windrose table. If not set,
-            nsectors=16, then each sector will be 360/16=22.5°, and the
+            nsector=16, then each sector will be 360/16=22.5°, and the
             resulting computed table will be aligned with the cardinals points.
         bins : 1D array or integer, optional
             number of bins, or a sequence of bins variable. If not set, bins=6,
@@ -449,15 +465,17 @@ class WindroseAxes(PolarAxes):
             (
                 self._info["table"],
                 np.reshape(
-                    self._info["table"][:, 0], (self._info["table"].shape[0], 1)
+                    self._info["table"][:, 0],
+                    (self._info["table"].shape[0], 1),
                 ),
-            )
+            ),
         )
 
-        offset = self._calm_circle()
+        self._calm_circle()
+        origin = 0
         for i in range(nbins):
-            val = vals[i, :] + offset
-            offset += vals[i, :]
+            val = vals[i, :] + origin
+            origin += vals[i, :]
             zorder = ZBASE + nbins - i
             patch = self.plot(angles, val, color=colors[i], zorder=zorder, **kwargs)
             self.patches_list.extend(patch)
@@ -481,7 +499,7 @@ class WindroseAxes(PolarAxes):
         ----------------
         nsector: integer, optional
             number of sectors used to compute the windrose table. If not set,
-            nsectors=16, then each sector will be 360/16=22.5°, and the
+            nsector=16, then each sector will be 360/16=22.5°, and the
             resulting computed table will be aligned with the cardinals points.
         bins : 1D array or integer, optional
             number of bins, or a sequence of bins variable. If not set, bins=6,
@@ -517,14 +535,16 @@ class WindroseAxes(PolarAxes):
             (
                 self._info["table"],
                 np.reshape(
-                    self._info["table"][:, 0], (self._info["table"].shape[0], 1)
+                    self._info["table"][:, 0],
+                    (self._info["table"].shape[0], 1),
                 ),
-            )
+            ),
         )
-        offset = self._calm_circle()
+        self._calm_circle()
+        origin = 0
         for i in range(nbins):
-            val = vals[i, :] + offset
-            offset += vals[i, :]
+            val = vals[i, :] + origin
+            origin += vals[i, :]
             zorder = ZBASE + nbins - i
             patch = self.fill(
                 np.append(angles, 0),
@@ -553,7 +573,7 @@ class WindroseAxes(PolarAxes):
         ----------------
         nsector : integer, optional
             number of sectors used to compute the windrose table. If not set,
-            nsectors=16, then each sector will be 360/16=22.5°, and the
+            nsector=16, then each sector will be 360/16=22.5°, and the
             resulting computed table will be aligned with the cardinals points.
         bins : 1D array or integer, optional
             number of bins, or a sequence of bins variable. If not set, bins=6
@@ -595,17 +615,17 @@ class WindroseAxes(PolarAxes):
         dtheta = 2 * np.pi / nsector
         opening = dtheta * opening
 
-        offs = self._calm_circle()
+        self._calm_circle()
 
         for j in range(nsector):
-            offset = offs
+            origin = 0
             for i in range(nbins):
                 if i > 0:
-                    offset += self._info["table"][i - 1, j]
+                    origin += self._info["table"][i - 1, j]
                 val = self._info["table"][i, j]
                 zorder = ZBASE + nbins - i
                 patch = mpl.patches.Rectangle(
-                    (angles[j] - opening / 2, offset),
+                    (angles[j] - opening / 2, origin),
                     opening,
                     val,
                     facecolor=colors[i],
@@ -634,7 +654,7 @@ class WindroseAxes(PolarAxes):
         ----------------
         nsector: integer, optional
             number of sectors used to compute the windrose table. If not set,
-            nsectors=16, then each sector will be 360/16=22.5°, and the
+            nsector=16, then each sector will be 360/16=22.5°, and the
             resulting computed table will be aligned with the cardinals points.
         bins : 1D array or integer, optional
             number of bins, or a sequence of bins variable. If not set, bins=6
@@ -669,17 +689,17 @@ class WindroseAxes(PolarAxes):
                 raise ValueError("edgecolor must be a string color")
         opening = np.linspace(0.0, np.pi / 16, nbins)
 
-        offs = self._calm_circle()
+        self._calm_circle()
 
         for j in range(nsector):
-            offset = offs
+            origin = 0
             for i in range(nbins):
                 if i > 0:
-                    offset += self._info["table"][i - 1, j]
+                    origin += self._info["table"][i - 1, j]
                 val = self._info["table"][i, j]
                 zorder = ZBASE + nbins - i
                 patch = mpl.patches.Rectangle(
-                    (angles[j] - opening[i] / 2, offset),
+                    (angles[j] - opening[i] / 2, origin),
                     opening[i],
                     val,
                     facecolor=colors[i],
@@ -740,7 +760,7 @@ class WindAxes(mpl.axes.Subplot):
         return (self, params)
 
 
-def histogram(direction, var, bins, nsector, normed=False, blowto=False):
+def histogram(direction, var, bins, nsector, normed=False, blowto=False, total=0):
     """
     Returns an array where, for each sector of wind
     (centred on the north), we have the number of time the wind comes with a
@@ -784,18 +804,18 @@ def histogram(direction, var, bins, nsector, normed=False, blowto=False):
         direction = direction + 180.0
         direction[direction >= 360.0] = direction[direction >= 360.0] - 360
 
-    table = histogram2d(x=var, y=direction, bins=[var_bins, dir_bins], normed=False)[0]
+    table = histogram2d(x=var, y=direction, bins=[var_bins, dir_bins], density=False)[0]
     # add the last value to the first to have the table of North winds
     table[:, 0] = table[:, 0] + table[:, -1]
     # and remove the last col
     table = table[:, :-1]
     if normed:
-        table = table * 100 / table.sum()
+        table = table * 100 / total
 
     return dir_edges, var_bins, table
 
 
-@docstring.copy(WindroseAxes.contour)
+@_copy_docstring(WindroseAxes.contour)
 def wrcontour(direction, var, ax=None, rmax=None, figsize=FIGSIZE_DEFAULT, **kwargs):
     """
     Draw contour probability density function and return Weibull
@@ -807,7 +827,7 @@ def wrcontour(direction, var, ax=None, rmax=None, figsize=FIGSIZE_DEFAULT, **kwa
     return ax
 
 
-@docstring.copy(WindroseAxes.contourf)
+@_copy_docstring(WindroseAxes.contourf)
 def wrcontourf(direction, var, ax=None, rmax=None, figsize=FIGSIZE_DEFAULT, **kwargs):
     ax = WindroseAxes.from_ax(ax, rmax=rmax, figsize=figsize)
     ax.contourf(direction, var, **kwargs)
@@ -815,7 +835,7 @@ def wrcontourf(direction, var, ax=None, rmax=None, figsize=FIGSIZE_DEFAULT, **kw
     return ax
 
 
-@docstring.copy(WindroseAxes.box)
+@_copy_docstring(WindroseAxes.box)
 def wrbox(direction, var, ax=None, rmax=None, figsize=FIGSIZE_DEFAULT, **kwargs):
     ax = WindroseAxes.from_ax(ax, rmax=rmax, figsize=figsize)
     ax.box(direction, var, **kwargs)
@@ -823,7 +843,7 @@ def wrbox(direction, var, ax=None, rmax=None, figsize=FIGSIZE_DEFAULT, **kwargs)
     return ax
 
 
-@docstring.copy(WindroseAxes.bar)
+@_copy_docstring(WindroseAxes.bar)
 def wrbar(direction, var, ax=None, rmax=None, figsize=FIGSIZE_DEFAULT, **kwargs):
     ax = WindroseAxes.from_ax(ax, rmax=rmax, figsize=figsize)
     ax.bar(direction, var, **kwargs)
@@ -831,7 +851,7 @@ def wrbar(direction, var, ax=None, rmax=None, figsize=FIGSIZE_DEFAULT, **kwargs)
     return ax
 
 
-@docstring.copy(WindAxes.pdf)
+@_copy_docstring(WindAxes.pdf)
 def wrpdf(
     var,
     bins=None,
@@ -954,7 +974,9 @@ def plot_windrose_df(
     """Plot windrose from a pandas DataFrame."""
     var = df[var_name].values
     direction = df[direction_name].values
-    return plot_windrose_np(direction, var, by=by, rmax=rmax, ax=ax, **kwargs)
+    return plot_windrose_np(
+        direction, var, kind=kind, by=by, rmax=rmax, ax=ax, **kwargs
+    )
 
 
 def plot_windrose_np(
@@ -986,5 +1008,5 @@ def plot_windrose_np(
     else:
         raise NotImplementedError(
             "'by' keyword not supported for now "
-            "https://github.com/scls19fr/windrose/issues/10"
+            "https://github.com/scls19fr/windrose/issues/10",
         )
